ShellRunner

Struct ShellRunner 

pub struct ShellRunner { /* private fields */ }
Shell runner for executing scripts

Implementations

Source

impl ShellRunner

pub fn new() -> Self

Create a new shell runner with the default shell

pub fn with_default_shell(shell: Shell) -> Self

Create a shell runner with a specific default shell

pub async fn run_script( &self, script: &str, env: &HashMap<String, String>, working_dir: &Path, config: &ShellConfig, ) -> ShellOutput

Execute a script using the default shell

pub async fn run_bash( &self, script: &str, env: &HashMap<String, String>, working_dir: &Path, config: &ShellConfig, ) -> ShellOutput

Execute a bash script

pub async fn run_pwsh( &self, script: &str, env: &HashMap<String, String>, working_dir: &Path, config: &ShellConfig, ) -> ShellOutput

Execute a PowerShell Core (pwsh) script

pub async fn run_powershell( &self, script: &str, env: &HashMap<String, String>, working_dir: &Path, config: &ShellConfig, ) -> ShellOutput

Execute a Windows PowerShell script

pub async fn run_script_streaming( &self, script: &str, env: &HashMap<String, String>, working_dir: &Path, config: &ShellConfig, on_output: OutputCallback, ) -> ShellOutput

Execute a script with real-time output streaming

pub fn to_step_result( &self, output: ShellOutput, step_name: Option<String>, display_name: Option<String>, fail_on_stderr: bool, duration: Duration, ) -> StepResult

Convert shell output to a step result