pub struct TaskRunner { /* private fields */ }Expand description
Task runner for executing Azure DevOps tasks
Implementations
Sourceimpl TaskRunner
impl TaskRunner
Sourcepub fn new(cache_dir: PathBuf) -> Self
pub fn new(cache_dir: PathBuf) -> Self
Create a new task runner with the specified cache directory
Sourcepub fn with_cache(cache: TaskCache) -> Self
pub fn with_cache(cache: TaskCache) -> Self
Create a task runner with a custom task cache
Sourcepub fn with_node_path(self, path: impl AsRef<Path>) -> Self
pub fn with_node_path(self, path: impl AsRef<Path>) -> Self
Set the Node.js path
Sourcepub fn with_powershell_path(self, path: impl AsRef<Path>) -> Self
pub fn with_powershell_path(self, path: impl AsRef<Path>) -> Self
Set the PowerShell path
Sourcepub async fn execute_task(
&self,
task_ref: &str,
inputs: &HashMap<String, String>,
env: &HashMap<String, String>,
working_dir: &Path,
) -> Result<StepResult, TaskRunnerError>
pub async fn execute_task( &self, task_ref: &str, inputs: &HashMap<String, String>, env: &HashMap<String, String>, working_dir: &Path, ) -> Result<StepResult, TaskRunnerError>
Execute a task