pub struct TaskCache { /* private fields */ }Expand description
Task cache for managing Azure DevOps tasks
Implementations
Sourceimpl TaskCache
impl TaskCache
Sourcepub fn with_config(config: TaskCacheConfig) -> Self
pub fn with_config(config: TaskCacheConfig) -> Self
Create a task cache with custom configuration
Sourcepub fn with_cache_dir(cache_dir: impl AsRef<Path>) -> Self
pub fn with_cache_dir(cache_dir: impl AsRef<Path>) -> Self
Create a task cache with a specific cache directory
Sourcepub fn parse_task_reference(
task_ref: &str,
) -> Result<(String, String), TaskCacheError>
pub fn parse_task_reference( task_ref: &str, ) -> Result<(String, String), TaskCacheError>
Parse a task reference (e.g., “Bash@3” or “DotNetCoreCLI@2.123.4”)
Sourcepub async fn get_task(
&self,
task_ref: &str,
) -> Result<CachedTask, TaskCacheError>
pub async fn get_task( &self, task_ref: &str, ) -> Result<CachedTask, TaskCacheError>
Get a task from the cache, downloading if necessary
Sourcepub async fn get_task_by_name_version(
&self,
name: &str,
version: &str,
) -> Result<CachedTask, TaskCacheError>
pub async fn get_task_by_name_version( &self, name: &str, version: &str, ) -> Result<CachedTask, TaskCacheError>
Get a task by name and version
Sourcepub fn clear_cache(&self) -> Result<()>
pub fn clear_cache(&self) -> Result<()>
Clear all cached tasks